==> zio-aws-applicationinsights_2.12-5.17.124.1-sources.jar: zio/aws/applicationinsights/model/ListLogPatternsResponse.scala <==
package zio.aws.applicationinsights.model
import zio.ZIO
import zio.aws.applicationinsights.model.primitives.{
  PaginationToken,
  ResourceGroupName
}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListLogPatternsResponse(
    resourceGroupName: Option[ResourceGroupName] = None,
    logPatterns: Option[
      Iterable[zio.aws.applicationinsights.model.LogPattern]
    ] = None,
    nextToken: Option[PaginationToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.applicationinsights.model.ListLogPatternsResponse = {
    import ListLogPatternsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.applicationinsights.model.ListLogPatternsResponse
      .builder()
      .optionallyWith(
        resourceGroupName.map(value =>
          ResourceGroupName.unwrap(value): java.lang.String
        )
      )(_.resourceGroupName)
      .optionallyWith(
        logPatterns.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.logPatterns)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.applicationinsights.model.ListLogPatternsResponse.ReadOnly =
    zio.aws.applicationinsights.model.ListLogPatternsResponse
      .wrap(buildAwsValue())
}
object ListLogPatternsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.applicationinsights.model.ListLogPatternsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.applicationinsights.model.ListLogPatternsResponse =
      zio.aws.applicationinsights.model.ListLogPatternsResponse(
        resourceGroupName.map(value => value),
        logPatterns.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def resourceGroupName: Option[ResourceGroupName]
    def logPatterns
        : Option[List[zio.aws.applicationinsights.model.LogPattern.ReadOnly]]
    def nextToken: Option[PaginationToken]
    def getResourceGroupName: ZIO[Any, AwsError, ResourceGroupName] =
      AwsError.unwrapOptionField("resourceGroupName", resourceGroupName)
    def getLogPatterns: ZIO[Any, AwsError, List[
      zio.aws.applicationinsights.model.LogPattern.ReadOnly
    ]] = AwsError.unwrapOptionField("logPatterns", logPatterns)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.applicationinsights.model.ListLogPatternsResponse
  ) extends zio.aws.applicationinsights.model.ListLogPatternsResponse.ReadOnly {
    override val resourceGroupName: Option[ResourceGroupName] = scala
      .Option(impl.resourceGroupName())
      .map(value =>
        zio.aws.applicationinsights.model.primitives.ResourceGroupName(value)
      )
    override val logPatterns
        : Option[List[zio.aws.applicationinsights.model.LogPattern.ReadOnly]] =
      scala
        .Option(impl.logPatterns())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.applicationinsights.model.LogPattern.wrap(item)
          }.toList
        )
    override val nextToken: Option[PaginationToken] = scala
      .Option(impl.nextToken())
      .map(value =>
        zio.aws.applicationinsights.model.primitives.PaginationToken(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.applicationinsights.model.ListLogPatternsResponse
  ): zio.aws.applicationinsights.model.ListLogPatternsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-applicationinsights_2.12-7.21.15.7-sources.jar: zio/aws/applicationinsights/model/ListLogPatternsResponse.scala <==
package zio.aws.applicationinsights.model
import zio.ZIO
import zio.aws.applicationinsights.model.primitives.{
  PaginationToken,
  AccountId,
  ResourceGroupName
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListLogPatternsResponse(
    resourceGroupName: Optional[ResourceGroupName] = Optional.Absent,
    accountId: Optional[AccountId] = Optional.Absent,
    logPatterns: Optional[
      Iterable[zio.aws.applicationinsights.model.LogPattern]
    ] = Optional.Absent,
    nextToken: Optional[PaginationToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.applicationinsights.model.ListLogPatternsResponse = {
    import ListLogPatternsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.applicationinsights.model.ListLogPatternsResponse
      .builder()
      .optionallyWith(
        resourceGroupName.map(value =>
          ResourceGroupName.unwrap(value): java.lang.String
        )
      )(_.resourceGroupName)
      .optionallyWith(
        accountId.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.accountId)
      .optionallyWith(
        logPatterns.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.logPatterns)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.applicationinsights.model.ListLogPatternsResponse.ReadOnly =
    zio.aws.applicationinsights.model.ListLogPatternsResponse
      .wrap(buildAwsValue())
}
object ListLogPatternsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.applicationinsights.model.ListLogPatternsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.applicationinsights.model.ListLogPatternsResponse =
      zio.aws.applicationinsights.model.ListLogPatternsResponse(
        resourceGroupName.map(value => value),
        accountId.map(value => value),
        logPatterns.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def resourceGroupName: Optional[ResourceGroupName]
    def accountId: Optional[AccountId]
    def logPatterns
        : Optional[List[zio.aws.applicationinsights.model.LogPattern.ReadOnly]]
    def nextToken: Optional[PaginationToken]
    def getResourceGroupName: ZIO[Any, AwsError, ResourceGroupName] =
      AwsError.unwrapOptionField("resourceGroupName", resourceGroupName)
    def getAccountId: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("accountId", accountId)
    def getLogPatterns: ZIO[Any, AwsError, List[
      zio.aws.applicationinsights.model.LogPattern.ReadOnly
    ]] = AwsError.unwrapOptionField("logPatterns", logPatterns)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.applicationinsights.model.ListLogPatternsResponse
  ) extends zio.aws.applicationinsights.model.ListLogPatternsResponse.ReadOnly {
    override val resourceGroupName: Optional[ResourceGroupName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.resourceGroupName())
        .map(value =>
          zio.aws.applicationinsights.model.primitives.ResourceGroupName(value)
        )
    override val accountId: Optional[AccountId] = zio.aws.core.internal
      .optionalFromNullable(impl.accountId())
      .map(value =>
        zio.aws.applicationinsights.model.primitives.AccountId(value)
      )
    override val logPatterns: Optional[
      List[zio.aws.applicationinsights.model.LogPattern.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.logPatterns())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.applicationinsights.model.LogPattern.wrap(item)
        }.toList
      )
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value =>
        zio.aws.applicationinsights.model.primitives.PaginationToken(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.applicationinsights.model.ListLogPatternsResponse
  ): zio.aws.applicationinsights.model.ListLogPatternsResponse.ReadOnly =
    new Wrapper(impl)
}
